@@ -26,7 +26,7 @@ class JoblibFile(File):
         """
         return joblib.load(self.path)
 
-    def write(self, data: Any) -> None:
+    def write(self, data: Any, **kwargs) -> None:
         """
         Writes data to file.
 
